@@ -2,7 +2,7 @@ library(DynareR)
 # We use "example1" of the Dynare example files to illustrate
 #how to use this function
 
-modelName<-"example1"
+# It is recommended to enclose your codes within single quotes.
 
 library(DynareR)
 
@@ -49,16 +49,13 @@ var e, u = phi*0.009*0.009;
 end;
 
 stoch_simul;'
-model<-modelName
-code<-DynareCodes
-run_dynare(model,code)
+
+run_dynare(model="run_dynare",code=DynareCodes)
 
 # You can create an absolute or relative path for the DynareR files.
 # The following writes and run mod file in "DynareR/run_dynare/"  folder
 # relative to the current path.
 
-path="DynareR/run_dynare"
 
-if(!dir.exists(path)) dir.create(path,recursive = T)
 
-run_dynare(model,code,path)
+run_dynare(model="run_dynare",code=DynareCodes,path="DynareR/run_dynare")
